==> python-libsbml-experimental-5.11.2.tar.gz: python-libsbml-experimental-5.11.2/base/sbml/validator/constraints/L1CompatibilityConstraintsDeclared.cxx <==
/**
 * @cond doxygenLibsbmlInternal
 *
 * @file    L1CompatibilityConstraintsDeclared.cxx
 * @brief   Declarations of constraints
 * @author  SBML Team
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2014 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

addConstraint(new VConstraintModel91001(*this));

addConstraint(new VConstraintModel91002(*this));

addConstraint(new VConstraintModel91003(*this));

addConstraint(new VConstraintModel91004(*this));

addConstraint(new VConstraintModel91005(*this));

addConstraint(new VConstraintModel91006(*this));

addConstraint(new VConstraintCompartment91007(*this));

addConstraint(new VConstraintSpeciesReference91008(*this));

addConstraint(new VConstraintSpeciesReference91009(*this));

addConstraint(new VConstraintUnit91010(*this));

addConstraint(new VConstraintSpecies91011(*this));

addConstraint(new VConstraintSpecies91012(*this));

addConstraint(new VConstraintModel91013(*this));

addConstraint(new VConstraintUnitDefinition91013(*this));

addConstraint(new VConstraintUnit91013(*this));

addConstraint(new VConstraintCompartment91013(*this));

addConstraint(new VConstraintSpecies91013(*this));

addConstraint(new VConstraintParameter91013(*this));

addConstraint(new VConstraintAssignmentRule91013(*this));

addConstraint(new VConstraintRateRule91013(*this));

addConstraint(new VConstraintAlgebraicRule91013(*this));

addConstraint(new VConstraintReaction91013(*this));

addConstraint(new VConstraintSpeciesReference91013(*this));

addConstraint(new VConstraintKineticLaw91013(*this));

addConstraint(new VConstraintModel91015(*this));

addConstraint(new VConstraintSpecies91015(*this));

addConstraint(new VConstraintReaction91016(*this));

addConstraint(new VConstraintModel91017(*this));

addConstraint(new VConstraintModel91018(*this));

addConstraint(new VConstraintCompartment99926(*this));

addConstraint(new VConstraintSpecies91019(*this));

addConstraint(new VConstraintReaction91020(*this));

addConstraint(new VConstraintAssignmentRule91020(*this));

addConstraint(new VConstraintRateRule91020(*this));

addConstraint(new VConstraintAlgebraicRule91020(*this));

addConstraint(new VConstraintInitialAssignment91020(*this));


/** @endcond */

==> python-libsbml-experimental-5.15.0.tar.gz: python-libsbml-experimental-5.15.0/base/sbml/validator/constraints/L1CompatibilityConstraintsDeclared.cxx <==
/**
 * @cond doxygenLibsbmlInternal
 *
 * @file    L1CompatibilityConstraintsDeclared.cxx
 * @brief   Declarations of constraints
 * @author  SBML Team
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2017 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

addConstraint(new VConstraintModel91001(*this));

addConstraint(new VConstraintModel91002(*this));

addConstraint(new VConstraintModel91003(*this));

addConstraint(new VConstraintModel91004(*this));

addConstraint(new VConstraintModel91005(*this));

addConstraint(new VConstraintModel91006(*this));

addConstraint(new VConstraintCompartment91007(*this));

addConstraint(new VConstraintSpeciesReference91008(*this));

addConstraint(new VConstraintSpeciesReference91009(*this));

addConstraint(new VConstraintUnit91010(*this));

addConstraint(new VConstraintSpecies91011(*this));

addConstraint(new VConstraintSpecies91012(*this));

addConstraint(new VConstraintModel91013(*this));

addConstraint(new VConstraintUnitDefinition91013(*this));

addConstraint(new VConstraintUnit91013(*this));

addConstraint(new VConstraintCompartment91013(*this));

addConstraint(new VConstraintSpecies91013(*this));

addConstraint(new VConstraintParameter91013(*this));

addConstraint(new VConstraintAssignmentRule91013(*this));

addConstraint(new VConstraintRateRule91013(*this));

addConstraint(new VConstraintAlgebraicRule91013(*this));

addConstraint(new VConstraintReaction91013(*this));

addConstraint(new VConstraintSpeciesReference91013(*this));

addConstraint(new VConstraintKineticLaw91013(*this));

addConstraint(new VConstraintModel91015(*this));

addConstraint(new VConstraintSpecies91015(*this));

addConstraint(new VConstraintReaction91016(*this));

addConstraint(new VConstraintModel91017(*this));

addConstraint(new VConstraintModel91018(*this));

addConstraint(new VConstraintCompartment99926(*this));

addConstraint(new VConstraintSpecies91019(*this));

addConstraint(new VConstraintReaction91020(*this));

addConstraint(new VConstraintAssignmentRule91020(*this));

addConstraint(new VConstraintRateRule91020(*this));

addConstraint(new VConstraintAlgebraicRule91020(*this));

addConstraint(new VConstraintInitialAssignment91020(*this));

addConstraint(new VConstraintUnit98001(*this));

addConstraint(new VConstraintFunctionDefinition98002(*this));

addConstraint(new VConstraintInitialAssignment98002(*this));

addConstraint(new VConstraintAssignmentRule98002(*this));

addConstraint(new VConstraintRateRule98002(*this));

addConstraint(new VConstraintAlgebraicRule98002(*this));

addConstraint(new VConstraintConstraint98002(*this));

addConstraint(new VConstraintKineticLaw98002(*this));

addConstraint(new VConstraintTrigger98002(*this));

addConstraint(new VConstraintDelay98002(*this));

addConstraint(new VConstraintPriority98002(*this));

addConstraint(new VConstraintEventAssignment98002(*this));

addConstraint(new ReportEmptyListOf(98003, *this));

addConstraint(new VConstraintFunctionDefinition98004(*this));

addConstraint(new VConstraintInitialAssignment98004(*this));

addConstraint(new VConstraintAssignmentRule98004(*this));

addConstraint(new VConstraintRateRule98004(*this));

addConstraint(new VConstraintAlgebraicRule98004(*this));

addConstraint(new VConstraintConstraint98004(*this));

addConstraint(new VConstraintKineticLaw98004(*this));

addConstraint(new VConstraintTrigger98004(*this));

addConstraint(new VConstraintDelay98004(*this));

addConstraint(new VConstraintPriority98004(*this));

addConstraint(new VConstraintEventAssignment98004(*this));

addConstraint(new NumericArgsMathCheck(98006, *this));

addConstraint(new IdNameNewOnSBase(98007, *this));

addConstraint(new VConstraintReaction98008(*this));

addConstraint(new VConstraintInitialAssignment98009(*this));

/** @endcond */
